@@ -96,7 +96,7 @@ void Kwappen::set_random()             // set random generator
 
 void Kwappen::eatblank()               // eat spaces (string)
 {
-  char i = 0, j = 0;
+  int i = 0, j = 0;
   while(zeitstr[i])
   {
     if (zeitstr[i] != ' ')
@@ -110,7 +110,7 @@ void Kwappen::eatblank()               // eat spaces (string)
 
 void Kwappen::start_turm()
 {
-  char reihe, spalte;
+  int reihe, spalte;
   swap = 0;                                  // clear computer stone swapflag
   swapbutton->setText(i18n("Swap stone 1x")); 
   swapbutton->setEnabled(true);
@@ -137,7 +137,8 @@ void Kwappen::start_turm()
 
 void Kwappen::draw_turmset()                 // move selected stone
 {
-  char i = 0, j = 0, farbe;
+  int i = 0, j = 0;
+  char farbe;
   farbe = turm[stein1old][stein2old];
   turm[stein1old][stein2old] = -1;
   for (i=0; i<=11; i++)                      // shrink column
@@ -156,7 +157,7 @@ void Kwappen::draw_turmset()                 // move selected stone
 
 void Kwappen::set_computer()                 // add computer stone on column top
 {
-  char i;
+  int i;
   i = 0;
   while (turm[i][spalte1] > 0) i++;
   turm[i][spalte1] = stein1;
@@ -166,7 +167,8 @@ void Kwappen::set_computer()                 // add computer stone on column top
 
 void Kwappen::vier_shrink()                  // four row shrink
 {
-  char reihe, tcheck1, tcheck2;
+  int reihe;
+  char tcheck1, tcheck2;
   for(reihe = 0; reihe <= 11; reihe++)
   {
     if (turm[reihe][0] > 0 && turm[reihe][1] > 0 && turm[reihe][2] > 0 && turm[reihe][3] > 0 )
@@ -197,7 +199,7 @@ void Kwappen::vier_shrink()                  // four row shrink
 
 void Kwappen::column_shrink()                // column shrink
 {
-  char reihe, spalte;
+  int reihe, spalte;
   char farbe1, farbe2;
   for(spalte = 0;  spalte <= 3; spalte++)
   {
@@ -224,7 +226,7 @@ void Kwappen::column_shrink()                // column shrink
 
 void Kwappen::turm_copy()
 {
-   char reihe, spalte;
+   int reihe, spalte;
    for(spalte = 0; spalte <= 3; spalte++)     // copy columns
    {
      for(reihe = 0; reihe <= 11 ; reihe++)
@@ -236,7 +238,7 @@ void Kwappen::turm_copy()
 
 void Kwappen::turm_shrinking()               // shrink columns
 {
-  char j, reihe, spalte;
+  int j, reihe, spalte;
   for(spalte = 0; spalte <= 3; spalte++)
   {
     j = 0;
@@ -265,9 +267,9 @@ void Kwappen::turm_reduce()                      // tower shrink algorithm
   repaint();
 }
 
-void Kwappen::turm_reverse(char spalte)           // reverse column
+void Kwappen::turm_reverse(int spalte)           // reverse column
 {
-  char i, j = 0;
+  int i, j = 0;
   for (i=0; i<=10; i++)
   {
     turmcpy[10-i][spalte] = turm[i][spalte];
@@ -281,10 +283,9 @@ void Kwappen::turm_reverse(char spalte)           // reverse column
   }
 }
 
-void Kwappen::turm_farbe(char spalte)           // create new tower
+void Kwappen::turm_farbe(int spalte)           // create new tower
 {
-  int tempzufall;
-  char i;
+  int i, tempzufall;
   turm[0][spalte] = random_color();             // color arms
   for(i=1; i<=5; i++)
   {
@@ -299,7 +300,7 @@ void Kwappen::turm_farbe(char spalte)           // create new tower
 
 void Kwappen::ende_check()                       // end checking
 {
-  char j, reihe, spalte;
+  int j, reihe, spalte;
   char win_or_lose = 0;
   for(spalte = 0;  spalte <= 3; spalte++)
   {
@@ -368,7 +369,7 @@ void Kwappen::setTextBox(QPainter *p)   // set graphic text (rules)
 void Kwappen::paintEvent(QPaintEvent*)              // paint event
 {
   QPainter p;
-  char reihe, spalte, pos;
+  int reihe, spalte, pos;
   QPointArray arrow(4);
 
   static QColor beige (250,245,137);
@@ -656,7 +657,7 @@ void Kwappen::showHighscore()              // show highscore
 void Kwappen::clearHighscore()             // clear highscore
 {
   FILE* stream;
-  char i;
+  int i;
   QMessageBox *mb = NULL;
   mb = new QMessageBox(i18n("Clear highscore table ?"),
               i18n("Are you sure ?"),
@@ -680,7 +681,7 @@ void Kwappen::clearHighscore()             // clear highscore
 void Highscore::loadHighscore()              // load highscore
 {
   FILE* stream;
-  char i;
+  int i;
   char tempstr[60];
   stream = fopen(home_path+"kwappen/kwappen_highscore.txt", "rt");
   if (! stream)
@@ -749,8 +750,7 @@ void Highscore::closeHighscore()  // hide highscore dialog
 
 char Highscore::testHighscore()    // test new highscore entry
 {
-  int zeit;
-  char i;
+  int i, zeit;
   zeit = highE->sec;
   loadHighscore();
   for (i = 0; i <= 49; i++)
@@ -766,8 +766,7 @@ char Highscore::testHighscore()    // test new highscore entry
 
 void HighscoreEdit::writeHighscore()  // write highscore file
 {
-  char i;
-  int zeit;
+  int i, zeit;
   FILE* stream;
   char tempstr[50];
   char playn[50][50];
@@ -957,7 +956,7 @@ void Kwappen::topWA(KApplication* app)                  // menu entries
 
   KPopupMenu *help = helpMenu(QString(i18n("KWappen"))
            + " " + VERSION
-           + "\n\nWritten by Jens Schulz 2002  GPL2"
+           + "\n\nWritten by Jens Schulz 2003  GPL2"
            + "\n(jschulz-lcs@t-online.de)"
            + "\n\nhttp://www.lcs-chemie.de");
 
