@@ -69,8 +69,6 @@ class Kwappen : public KMainWindow
   char start;
   char turm[12][4];   // 12 rows, 4 columns
   char turmcpy[12][4];
-  char stein1, steinx, steiny, stein1old, stein2old, spalte1;
-  char own_row, own_col, own_color, comp_row, comp_col, comp_color;
   char found;
   char langswap;  // flag for language swap
   char swap;
@@ -80,7 +78,10 @@ class Kwappen : public KMainWindow
 
   char zeitstr[50];  // second string
 
-  void turm_farbe(char);
+  int stein1, steinx, steiny, stein1old, stein2old, spalte1;
+  int own_row, own_col, own_color, comp_row, comp_col, comp_color;
+
+  void turm_farbe(int);
   void draw_turmset();
   void set_computer();
   void turm_shrink();
@@ -91,7 +92,7 @@ class Kwappen : public KMainWindow
   void turm_copy();
   void turm_shrinking();
   void turm_reduce();
-  void turm_reverse(char);
+  void turm_reverse(int);
   void setTextBox(QPainter*);
 
   int random_color();
